@@ -1,6 +1,5 @@
 package Webqq::Client::Plugin::CpanRecentModule;
 use AE;
-use Encode;
 use XML::Simple;
 use POSIX qw(mktime);
 use Storable qw(store retrieve);
@@ -62,7 +61,6 @@ sub call{
                         ;
                     }
                     my $msg = "Hi, CPAN有新模块发布:\n" . join("\n",@msg);
-                    $msg = encode("utf8",$msg);
                     for my $g (@{ $client->{qq_database}{group} }){
                         $client->send_group_message(to_uin=>$g->{ginfo}{gid},content=>$msg);
                     }
